import { Request, Response } from 'express';
import { prisma } from '../lib/prisma';

export const pageController = {
  // Créer une nouvelle page
  async create(req: Request, res: Response) {
    try {
      const { title, parentId, userId } = req.body;

      const page = await prisma.page.create({
        data: {
          title,
          parentId,
          userId,
        },
        include: {
          blocks: true,
        },
      });

      return res.status(201).json(page);
    } catch (error) {
      return res.status(500).json({ error: 'Erreur lors de la création de la page' });
    }
  },

  // Obtenir une page par son ID avec ses blocs
  async getById(req: Request, res: Response) {
    try {
      const { id } = req.params;
      const page = await prisma.page.findUnique({
        where: { id },
        include: {
          blocks: {
            orderBy: {
              order: 'asc',
            },
          },
        },
      });

      if (!page) {
        return res.status(404).json({ error: 'Page non trouvée' });
      }

      return res.json(page);
    } catch (error) {
      return res.status(500).json({ error: 'Erreur lors de la récupération de la page' });
    }
  },

  // Mettre à jour une page
  async update(req: Request, res: Response) {
    try {
      const { id } = req.params;
      const { title, blocks } = req.body;

      // Supprimer tous les blocs existants
      await prisma.block.deleteMany({
        where: { pageId: id },
      });

      // Créer les nouveaux blocs
      const newBlocks = await Promise.all(
        blocks.map((block: any) =>
          prisma.block.create({
            data: {
              type: block.type,
              content: block.content,
              order: block.order,
              pageId: id,
            },
          })
        )
      );

      // Mettre à jour la page
      const page = await prisma.page.update({
        where: { id },
        data: {
          title,
        },
        include: {
          blocks: {
            orderBy: {
              order: 'asc',
            },
          },
        },
      });

      return res.json(page);
    } catch (error) {
      console.error('Erreur lors de la mise à jour:', error);
      return res.status(500).json({ error: 'Erreur lors de la mise à jour de la page' });
    }
  },

  // Supprimer une page
  async delete(req: Request, res: Response) {
    try {
      const { id } = req.params;

      await prisma.page.delete({
        where: { id },
      });

      return res.status(204).send();
    } catch (error) {
      return res.status(500).json({ error: 'Erreur lors de la suppression de la page' });
    }
  },

  // Récupérer toutes les pages
  async getAll(req: Request, res: Response) {
    try {
      const pages = await prisma.page.findMany({
        include: {
          blocks: {
            orderBy: {
              order: 'asc',
            },
          },
        },
        orderBy: {
          updatedAt: 'desc',
        },
      });
      return res.json(pages);
    } catch (error) {
      console.error('Erreur lors de la récupération des pages:', error);
      return res.status(500).json({ error: 'Erreur lors de la récupération des pages' });
    }
  },
}; 